//--------------------------------------------------------------
// File     : stm32_ub_am2301.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_AM2301_H
#define __STM32F4_UB_AM2301_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_tim.h"
#include "misc.h"




//--------------------------------------------------------------
// Datenpin vom AM2301
//--------------------------------------------------------------
#define AM2301_PIN               GPIO_Pin_3
#define AM2301_PORT              GPIOD
#define AM2301_CLK               RCC_AHB1Periph_GPIOD



//--------------------------------------------------------------
// Timer
// F_TIM = 84 MHz / (prescaler+1) / (periode+1)
// F_TIM = 1MHz => 1us
//--------------------------------------------------------------
#define AM2301_PRESCALE   1
#define AM2301_PERIOD     41


//--------------------------------------------------------------
typedef enum {
  AM2301_OK    =0,    // Auslesen war OK
  AM2301_NOTREADY,    // Sensor noch nicht bereit
  AM2301_ERROR        // Fehler beim auslesen
}AM2301_STATUS_t;


//--------------------------------------------------------------
// Struktur vom AM2301
//--------------------------------------------------------------
typedef struct {
  float humidity;          // Luftfeuchte in prozent (z.B. 65.8)
  float temperature;       // Temperatur in grad (z.B. 23.2 oder -10.4);
}AM2301_t;
AM2301_t AM2301;


//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void UB_AM2301_Init(void);
AM2301_STATUS_t UB_AM2301_Read(void);



//--------------------------------------------------------------
#endif // __STM32F4_UB_AM2301_H
